@@ -52,6 +52,7 @@ class GCPInstance(VMInterface):
         projectid=None,
         machine_type=None,
         filesystem_size=None,
+        on_host_maintenance=None,
         source_image=None,
         docker_image=None,
         network=None,
@@ -61,12 +62,16 @@ class GCPInstance(VMInterface):
         bootstrap=None,
         gpu_instance=None,
         auto_shutdown=None,
+        preemptible=False,
         **kwargs,
     ):
         super().__init__(**kwargs)
 
         self.cluster = cluster
         self.config = config
+        self.on_host_maintenance = on_host_maintenance or self.config.get(
+            "on_host_maintenance"
+        )
         self.projectid = projectid or self.config.get("projectid")
         self.zone = zone or self.config.get("zone")
 
@@ -84,6 +89,7 @@ class GCPInstance(VMInterface):
         self.gpu_instance = gpu_instance
         self.bootstrap = bootstrap
         self.auto_shutdown = auto_shutdown
+        self.preemptible = preemptible
 
         self.general_zone = "-".join(self.zone.split("-")[:2])  # us-east1-c -> us-east1
 
@@ -146,9 +152,9 @@ class GCPInstance(VMInterface):
             },
             "labels": {"container-vm": "dask-cloudprovider"},
             "scheduling": {
-                "preemptible": "false",
-                "onHostMaintenance": "TERMINATE",
-                "automaticRestart": "true",
+                "preemptible": ("true" if self.preemptible else "false"),
+                "onHostMaintenance": self.on_host_maintenance.upper(),
+                "automaticRestart": ("false" if self.preemptible else "true"),
                 "nodeAffinities": [],
             },
             "shieldedInstanceConfig": {
@@ -268,6 +274,7 @@ class GCPScheduler(SchedulerMixin, GCPInstance):
     """Scheduler running in a GCP instance."""
 
     def __init__(self, *args, **kwargs):
+        kwargs.pop("preemptible", None)  # scheduler instances are not preemptible
         super().__init__(*args, **kwargs)
 
     async def start(self):
@@ -422,6 +429,8 @@ class GCPCluster(VMCluster):
         You can see a list of GPUs available in each zone with ``gcloud compute accelerator-types list``.
     filesystem_size: int (optional)
         The VM filesystem size in GB. Defaults to ``50``.
+    on_host_maintenance: str (optional)
+        The Host Maintenance GCP option.  Defaults to ``TERMINATE``.
     n_workers: int (optional)
         Number of workers to initialise the cluster with. Defaults to ``0``.
     bootstrap: bool (optional)
@@ -447,6 +456,8 @@ class GCPCluster(VMCluster):
         Configures communication security in this cluster. Can be a security
         object, or True. If True, temporary self-signed credentials will
         be created automatically. Default is ``True``.
+    preemptible: bool (optional)
+        Whether to use preemptible instances for workers in this cluster. Defaults to ``False``.
 
     Examples
     --------
@@ -501,7 +512,7 @@ class GCPCluster(VMCluster):
     Source Image: projects/ubuntu-os-cloud/global/images/ubuntu-minimal-1804-bionic-v20201014
     Docker Image: daskdev/dask:latest
     Machine Type: n1-standard-1
-    Filesytsem Size: 50
+    Filesystem Size: 50
     N-GPU Type:
     Zone: us-east1-c
     Creating scheduler instance
@@ -526,6 +537,7 @@ class GCPCluster(VMCluster):
         zone=None,
         network=None,
         machine_type=None,
+        on_host_maintenance=None,
         source_image=None,
         docker_image=None,
         ngpus=None,
@@ -533,6 +545,7 @@ class GCPCluster(VMCluster):
         filesystem_size=None,
         auto_shutdown=None,
         bootstrap=True,
+        preemptible=None,
         **kwargs,
     ):
 
@@ -558,6 +571,8 @@ class GCPCluster(VMCluster):
             "source_image": source_image or self.config.get("source_image"),
             "docker_image": docker_image or self.config.get("docker_image"),
             "filesystem_size": filesystem_size or self.config.get("filesystem_size"),
+            "on_host_maintenance": on_host_maintenance
+            or self.config.get("on_host_maintenance"),
             "zone": zone or self.config.get("zone"),
             "machine_type": self.machine_type,
             "ngpus": ngpus or self.config.get("ngpus"),
@@ -566,6 +581,9 @@ class GCPCluster(VMCluster):
             "gpu_instance": self.gpu_instance,
             "bootstrap": self.bootstrap,
             "auto_shutdown": self.auto_shutdown,
+            "preemptible": preemptible
+            if preemptible is not None
+            else self.config.get("preemptible"),
         }
         self.scheduler_options = {**self.options}
         self.worker_options = {**self.options}
